/* ========================================================================
   WarpMedia Skin Resource Type Structs
   Revision 3, 2001-06-05
   (c) 2001, Software Developers Guild
======================================================================== */

#ifndef _RT_H
#define _RT_H

   #include <Skin_RC.h>

   #define V_SkinEngineVersion       0x0111 // Current version of Skin Engine

   struct SRT_Skin {
      USHORT ResourceType;
      USHORT EngineVersion;
      USHORT ID_SkinName;
      USHORT ID_SkinComment;
      USHORT ID_Looks[1];
   };

   struct SRT_Look {
      USHORT ResourceType;
      USHORT ID_NormalMode;
      USHORT ID_DarkMode;
   };

   struct SRT_Mode {
      USHORT ResourceType;
      USHORT Quadrant;

      union {
         struct {
            USHORT Red;
            USHORT Green;
            USHORT Blue;
         } Colour;

         struct {
            USHORT x;
            USHORT y;
            USHORT Reserved;
         } Coordinate;
      } Transparent;

      // 0 = Disabled 
      // 1 = Enabled, RGB value specified (requires PM in 24bpp mode or higher)
      // 2 = Enabled, X/Y coordinate specified
      USHORT TransparentMode; 

      USHORT ID_BmpBackground;
      USHORT NumControls;
      USHORT ID_Controls[1];
   };
   // Note: When a resource of type RT_Mode has been loaded, the memory
   //       following directly after this record will be occupied by an
   //       ARRAY [0..NumControls-1] of uShort.

   struct SRT_CtrlGeneric {
      USHORT ResourceType;
      USHORT ConnectsTo;
      USHORT ControlType;
   };

   struct SRT_CtrlBitmap {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_Bmp;
   };

   struct SRT_CtrlPushButton {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_BmpShape;
      USHORT ID_BmpUp;
      USHORT ID_BmpDown;
      USHORT ID_BmpMouseOver;
   };

   struct SRT_Ctrl2StateButton {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_BmpShape;
      USHORT ID_BmpEnabledUp;
      USHORT ID_BmpEnabledDown;
      USHORT ID_BmpDisabledUp;
      USHORT ID_BmpDisabledDown;
      USHORT ID_BmpEnabledMouseOver;
      USHORT ID_BmpDisabledMouseOver;
   };

   struct SRT_CtrlSimpleSlider {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT Vertical;  // 0 == Horizontal, 1 == Vertical
      USHORT ID_BmpShape;
      USHORT ID_BmpMin;
      USHORT ID_BmpMax;
   };

   struct SRT_CtrlSlider {
      USHORT ResourceType;
      USHORT BGX;
      USHORT BGY;
      USHORT HandleX;
      USHORT HandleY;
      USHORT HandleMaxX;        // Ignored when vertical
      USHORT HandleMaxY;        // Ignored when horizontal
      USHORT Vertical;          // 0 == Horizontal, 1 == Vertical
      USHORT ID_BmpShape;
      USHORT ID_BmpBackground;
      USHORT ID_BmpHandleUp;
      USHORT ID_BmpHandleDown;
   };

   struct SRT_2StateIndicator {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_BmpEnabled;
      USHORT ID_BmpDisabled;
   };

   struct SRT_3StateIndicator {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_BmpEnabled1;
      USHORT ID_BmpEnabled2;
      USHORT ID_BmpDisabled;
   };

   struct SRT_Counter {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT X2;
      USHORT Y2;
      USHORT ID_DigitFont;
      USHORT NumDigits;
      struct {
         USHORT X;
         USHORT Y;
         USHORT ID_BmpOn;
         USHORT ID_BmpOff;
      } Digits[1];
   };

   struct SRT_DigitFont {
      USHORT ResourceType;
      USHORT ID_Bmp_Digits[11];   // Disabled followed by 0 to 9
   };

   struct SRT_Scroll {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT X2;
      USHORT Y2;
      USHORT Mode;
      USHORT StartDelay;
      USHORT TimerID;
      USHORT TickInterval;
      USHORT PixelPerTick;
      USHORT Space;
      USHORT Color_FG_Red;
      USHORT Color_FG_Green;
      USHORT Color_FG_Blue;
      USHORT Color_BG_Red;
      USHORT Color_BG_Green;
      USHORT Color_BG_Blue;
      USHORT ID_Font;
   };

   struct SRT_LookSwitch {
      USHORT ResourceType;
      USHORT ID_NewLookString;
      USHORT ControlTypeButton;  // TwoState or PushButton.
   };

   struct SRT_StateIndicator {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT ID_BmpDisabled;
      USHORT ID_BmpStates[1];
   };

   struct SRT_AnimatedBitmap {
      USHORT ResourceType;
      USHORT TimerID;
      struct {
         USHORT ID_Bmp;
         USHORT msActiveTime;
      } Bitmaps[1];
   };

   struct SRT_ExternalBitmap {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT X2;
      USHORT Y2;
      USHORT ID_BmpFilename;
   };

   struct SRT_MultipleBitmaps {
      USHORT ResourceType;
      struct {
         USHORT ID_Bmp;
      } Bitmaps[1];
   };

   struct SRT_SystemFont {
      USHORT ResourceType;
      USHORT FontX;
      USHORT FontY;
      char FontName[1];
   };

   struct SRT_BitmapFont {
      USHORT ResourceType;
      USHORT SpacingX;
      USHORT SpacingY;
      USHORT ID_BmpDefault;
      USHORT DefaultAscii;   // When some character is unavailable, use this one.
      struct {
         USHORT FromAscii;
         USHORT ToAscii;
         USHORT FirstCharX;
         USHORT FirstCharY;
         USHORT CharSizeX;
         USHORT CharSizeY;
         USHORT SpaceToNextCharX;
         USHORT SpaceToNextCharY;
         USHORT ID_Bmp;
      } Characters[1];
   };

   struct SRT_MetaControl {
      USHORT ResourceType;
      USHORT X;
      USHORT Y;
      USHORT X2;
      USHORT Y2;
      USHORT fCycleWithButton1;
      USHORT fContextMenu;
      USHORT ID_Controls[1];
   };

#endif
